@@ -19,12 +19,12 @@ def register_all_groups():
 @register_main()
 def main():
     """
-    pycontacts will help you write makefiles
+    pycontacts is a collection of utilities to help interact with google contacts
     """
     pylogconf.core.setup()
     register_all_groups()
     get_pytconf().config_arg_parse_and_launch()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
